==> python-weka-wrapper3-0.2.12.tar.gz: python-weka-wrapper3-0.2.12/README.md <==
# python-weka-wrapper3

Python wrapper for the Java machine learning workbench [Weka](http://www.cs.waikato.ac.nz/~ml/weka/)
using the [python-javabridge](https://pypi.python.org/pypi/python-javabridge) library.

Requirements:

* Python 3
  * python-javabridge (>= 4.0.0)
  * matplotlib (optional)
  * pygraphviz (optional)
  * PIL (optional)
  * lxml (optional)
* OpenJDK 11 (or later)

Uses:
* Weka (3.9.6)


## Installation

Detailed instructions on installing the library on various operating systems are located here:

https://fracpete.github.io/python-weka-wrapper3/install.html

Please note, that you need a build environment to compile some libraries from source.


## Docker

python-weka-wrapper3 also offers pre-built Docker images, making it easy to run the
tool without having to install it. See [here](docker/README.md) for more information.


## Forum

You can post questions, patches or enhancement requests in the following Google Group:

https://groups.google.com/forum/#!forum/python-weka-wrapper


## Examples

* The [Examples](https://fracpete.github.io/python-weka-wrapper3/examples.html)
  section in the documentation demonstrates how to use the API. 
* The [python-weka-wrapper-examples3](https://github.com/fracpete/python-weka-wrapper3-examples)
  repository contains plenty of example code for the various APIs.


## Documentation

The complete documentation for the library is available from here:

https://fracpete.github.io/python-weka-wrapper3/


## Download statistics

For viewing recent download statistics, go to *pypistats*:

https://pypistats.org//api/packages/python-weka-wrapper3/recent

==> python-weka-wrapper3-0.3.2.tar.gz: python-weka-wrapper3-0.3.2/README.md <==
# python-weka-wrapper3

Python wrapper for the Java machine learning workbench [Weka](http://www.cs.waikato.ac.nz/~ml/weka/)
using the [jpype](https://github.com/jpype-project/jpype) library.

Requirements:

* Python 3
  * jpype1
  * matplotlib (optional)
  * pygraphviz (optional)
  * PIL (optional)
  * lxml (optional)
* OpenJDK 11 (or later)

Uses:
* Weka (3.9.6)


## Installation

Detailed instructions on installing the library on various operating systems are located here:

https://fracpete.github.io/python-weka-wrapper3/install.html

Please note, that you need a build environment to compile some libraries from source.


## Docker

python-weka-wrapper3 also offers pre-built Docker images, making it easy to run the
tool without having to install it. See [here](docker/README.md) for more information.


## Forum

You can post questions, patches or enhancement requests in the following Google Group:

https://groups.google.com/forum/#!forum/python-weka-wrapper


## Examples

* The [Examples](https://fracpete.github.io/python-weka-wrapper3/examples.html)
  section in the documentation demonstrates how to use the API. 
* The [python-weka-wrapper-examples3](https://github.com/fracpete/python-weka-wrapper3-examples)
  repository contains plenty of example code for the various APIs.


## Documentation

The complete documentation for the library is available from here:

https://fracpete.github.io/python-weka-wrapper3/


## Download statistics

For viewing recent download statistics, go to *pypistats*:

https://pypistats.org//api/packages/python-weka-wrapper3/recent
